==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebRowDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDataEventArgsDetailDescriptionMetadata } from "./WebRowDataEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDescription } from "./WebRowDataEventArgsDescription";
/**
 * @hidden
 */
export let WebRowDataEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowDataEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowDataEventArgsDescriptionMetadata.a == null) {
                WebRowDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowDataEventArgsDescriptionMetadata.c(WebRowDataEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebRowDataEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRowDataEventArgsDescriptionMetadata.a);
            WebRowDataEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowDataEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebRowDataEventArgsDetail");
        }
        static d(a) {
            WebRowDataEventArgsDescriptionMetadata.b(a);
            a.ad("WebRowDataEventArgs", () => new WebRowDataEventArgsDescription());
            a.ac("WebRowDataEventArgs", WebRowDataEventArgsDescriptionMetadata.a);
        }
    }
    WebRowDataEventArgsDescriptionMetadata.$t = markType(WebRowDataEventArgsDescriptionMetadata, 'WebRowDataEventArgsDescriptionMetadata');
    WebRowDataEventArgsDescriptionMetadata.a = null;
    return WebRowDataEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebRowDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDataEventArgsDetailDescriptionMetadata } from "./WebRowDataEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDescription } from "./WebRowDataEventArgsDescription";
/**
 * @hidden
 */
export let WebRowDataEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowDataEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowDataEventArgsDescriptionMetadata.a == null) {
                WebRowDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowDataEventArgsDescriptionMetadata.c(WebRowDataEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebRowDataEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRowDataEventArgsDescriptionMetadata.a);
            WebRowDataEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowDataEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebRowDataEventArgsDetail");
        }
        static d(a) {
            WebRowDataEventArgsDescriptionMetadata.b(a);
            a.ae("WebRowDataEventArgs", () => new WebRowDataEventArgsDescription());
            a.ad("WebRowDataEventArgs", WebRowDataEventArgsDescriptionMetadata.a);
        }
    }
    WebRowDataEventArgsDescriptionMetadata.$t = markType(WebRowDataEventArgsDescriptionMetadata, 'WebRowDataEventArgsDescriptionMetadata');
    WebRowDataEventArgsDescriptionMetadata.a = null;
    return WebRowDataEventArgsDescriptionMetadata;
})();
